function [ xml_file ] = xml_file( p_filename, p_filemask )
%FLOAT_METADATA Loads xml files into a matlab cell.
%   Loads either one xml file or all xml files from the given directory.
%
%   Parameter:
%   p_filename:     string, if empty the complete directory is being loaded.
%   p_filemask:     string, the filemask of the files to be selected, for
%                   example: *float_*
%   
%   Returns:
%   xml_file:       cell, containing all files that have been read.

%% Initialize return variables
xml_file = false;

%% Parameter check
parameter_error = false;
file_only = false;

if (~ischar(p_filename) || (exist('p_filemask', 'var') && ~ischar(p_filemask)))
    parameter_error = true;
end

if (~isdir(p_filename))
    file_only = true;
end

if (parameter_error) % display error message
    disp([ mfilename ': Wrong parameter! Please check your input parameters carefully!']);
    return;
else % do some cleanup
    clear parameter_error;
end

%% Check operating system
if (ismac || isunix)
    folder_separator = '/';
elseif (ispc)
    folder_separator = '\';
end

%% Load metadata files
if (file_only)
    if ~exist(p_filename, 'file') % warn user
        warning([mfilename ': Float metadata file ' p_filename ' does not exist!']);
        return
    end
    xml_file = utils.xml_read(p_filename);
else
    if (exist('p_filemask', 'var'))
        filenames = struct2table(dir([p_filename folder_separator p_filemask '.xml']));
    else
        filenames = struct2table(dir([p_filename folder_separator '*.xml']));
    end
    
    absolute_filenames = cellfun(@(name) [p_filename folder_separator name], filenames.name, 'UniformOutput', false);
    xml_file = cellfun(@(name) utils.xml_read(name), absolute_filenames, 'UniformOutput', false);
end

end

