function [ unread_messages, folder ] = fetch_unread( p_imapstore, p_foldername )
%FETCH_UNREAD Fetches all messages that are flagged as unread on the server.
%   Fetches all messages that are flagged as unread in the given folder.
%
%   Parameters:
%   p_imapstore:        The imapstore object.
%   p_foldername:       The folder name where the messages are stored.
%
%   Returns:
%   unread_messages:    The messages that have been fetched.
%   folder:             The folder object.

%% Initialize return variables
unread_messages = false;

%% Parameter check
parameter_error = false;

if (~ischar(p_foldername))
    parameter_error = true;
end

if (parameter_error) % display error message
    disp([ mfilename ': Wrong parameter! Please check your input parameters carefully!']);
    return;
else % do some cleanup
    clear parameter_error;
end

%% Check connection

if (~p_imapstore.isConnected())
    disp('IMAPStore not connected, trying to reconnect...');
    p_imapstore.connect();
    if (~p_imapstore.isConnected())
        warning('IMAPStore reconnect failed. Please check your configuration!');
        return;
    end
end

%% Get and open folder
folder = p_imapstore.getFolder(p_foldername);
folder.open(folder.READ_ONLY);

%% Fetch all unread messages

% there are difficulties accessing static class members of an inner java
% class. This solution has been found at:
% http://undocumentedmatlab.com/blog/accessing-internal-java-class-members
search_flag = javax.mail.Flags(); % create search flag
tmp = search_flag.getClass.getDeclaredClasses;
seen_flag = tmp(1).getField('SEEN').get(1);
clear tmp;
search_flag.add(seen_flag);
flagterm = javax.mail.search.FlagTerm(search_flag, false);
unread_messages = folder.search(flagterm);


end

