timer = tic;
disp([mfilename ': Adding dependencies ...']);
cd('C:\FLOAT DEPLOYMENT ON POLARSTERN\FLOAT DATA PROCESSING AND ANALYSIS');
addpath(genpath('C:\FLOAT DEPLOYMENT ON POLARSTERN\FLOAT DATA PROCESSING AND ANALYSIS'));

disp([mfilename ': Loading configuration file...']);
% load program config
config = nemo.load.config('etc\nemo2profile.conf');
disp([mfilename ': ...done!']);
disp([mfilename ': Loading float metadata files...']);
% load all floats that have to be processed
metadata = nemo.load.float_metadata('etc\float_metadata');
disp([mfilename ': ...done!']);

disp([mfilename ': Downloading and processing mails...']);
% download and process mails
nemo.float.fetch_process_mails(config, metadata);
disp([mfilename ': ...done!']);
disp([mfilename ': Converting sbd attachments and extracting transmission information...']);
awi_struct = nemo.load.floats2nemostruct(config, metadata);
disp([mfilename ': ...done!']);

%% Remove logical cells (without profiles)
awi_struct = awi_struct(~cellfun(@(x) isa(x, 'logical'), awi_struct));

%% Manual quality check
awi_struct = nemo.postprocessing.delete_profile(awi_struct, 239, 1);

%% Process data

disp([mfilename ': Creating second order information...']);
% possible estimation methods:
% 'time based': memory consumption EXTREMLY high, but most descriptive
% 'position based': less memory consumption, positions equally split
% 'nan': most leightweight estimation, using NaN for unknown positions
awi_struct = ...
    nemo.postprocessing.position.create_best_guess( ...
    awi_struct, 'time based' ...
    );
awi_struct = nemo.postprocessing.datetime.create_best_guess(awi_struct);
disp([mfilename ': ... done!' ]);
disp([mfilename ': Doing quality check...' ]);
awi_struct = nemo.postprocessing.quality_check(awi_struct);
disp([mfilename ': ... done!']);
disp([mfilename ': Generating RFB files and save to disk...']);
[success, rfb_floats] = nemo.rfb.create_and_save_collection(awi_struct, config, metadata);
if (~success)
    disp([mfilename ': ... failed!']);
else
    save([config.OUTPUT_FILES.output_path 'rfb_floats.mat'], 'rfb_floats');
    disp([mfilename ': ... done!']);
end
disp([mfilename ': Saving data to ' config.OUTPUT_FILES.output_path '...']);
nemo.save_data(awi_struct, config);
save([config.OUTPUT_FILES.output_path 'awi_struct.mat'], 'awi_struct');
save([config.OUTPUT_FILES.output_path 'config.mat'], 'config');
save([config.OUTPUT_FILES.output_path 'metadata.mat'], 'metadata');
disp([mfilename ': ... done!']);
    
disp([mfilename ': Generating analysis items...']);
if ~nemo.analysis.create_csv_table(awi_struct, config)
    warning('Creating overview table failed!');
end
if ~nemo.plot.floats(awi_struct, config, 'south', false)
    warning('Creating overview south plot failed!');
end
if ~nemo.plot.floats(awi_struct, config, 'south', true)
    warning('Creating plot for every single float failed!');
end
if ~nemo.plot.arrival_of_profiles(awi_struct, config)
    warning('Creating arrival of profiles plot failed!');
end
disp([mfilename ': ... done!']);

disp([mfilename ': Uploading float data to server ...']);
% Upload data to server
if (~nemo.ftp.upload(config))
    disp([mfilename ': Uploading data failed!']);
else
    disp([mfilename ': Uploading data successful!']);
end
disp([mfilename ': Processing nemo data took ' num2str(toc(timer)) ' seconds!']);